@@ -22,7 +22,7 @@ pub struct Table {
     pub info: Rc<ColInfo>,
 
     /// List of indexes.
-    ixlist: RefCell<IxList>,
+    pub ixlist: RefCell<IxList>,
 
     /// Table id in sys.Table.
     pub id: i64,
@@ -262,8 +262,8 @@ impl<'d, 'i> Access<'d, 'i> {
         String::from_utf8(bytes).unwrap()
     }
     /// Extract Id from byte data.
-    pub fn id(&self) -> i64 {
-        util::getu64(self.data, 0) as i64
+    pub fn id(&self) -> u64 {
+        util::getu64(self.data, 0)
     }
 }
 
@@ -283,6 +283,14 @@ impl<'d, 'i> WriteAccess<'d, 'i> {
             self.info.siz(colnum),
         );
     }
+    /// Extract int from byte data for column number colnum.
+    pub fn int(&self, colnum: usize) -> i64 {
+        util::get(self.data, self.info.off[colnum], self.info.siz(colnum)) as i64
+    }
+    /// Extract Id from byte data.
+    pub fn id(&self) -> u64 {
+        util::getu64(self.data, 0)
+    }
 }
 
 /// Table name, column names/types and other calculated values for a table.
